Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2483)

Unified Diff: third_party/boto/boto/ec2/autoscale/group.py

Issue 698893003: Update checked in version of gsutil to version 4.6 (Closed) Base URL: http://dart.googlecode.com/svn/third_party/gsutil/
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/boto/boto/ec2/autoscale/group.py
===================================================================
--- third_party/boto/boto/ec2/autoscale/group.py (revision 33376)
+++ third_party/boto/boto/ec2/autoscale/group.py (working copy)
@@ -146,9 +146,9 @@
:param placement_group: Physical location of your cluster placement
group created in Amazon EC2.
- :type vpc_zone_identifier: str
- :param vpc_zone_identifier: The subnet identifier of the Virtual
- Private Cloud.
+ :type vpc_zone_identifier: str or list
+ :param vpc_zone_identifier: A comma-separated string or python list of
+ the subnet identifiers of the Virtual Private Cloud.
:type tags: list
:param tags: List of :class:`boto.ec2.autoscale.tag.Tag`s
@@ -188,6 +188,8 @@
self.health_check_type = health_check_type
self.placement_group = placement_group
self.autoscaling_group_arn = None
+ if type(vpc_zone_identifier) is list:
+ vpc_zone_identifier = ','.join(vpc_zone_identifier)
self.vpc_zone_identifier = vpc_zone_identifier
self.instances = None
self.tags = tags or None
« no previous file with comments | « third_party/boto/boto/ec2/autoscale/__init__.py ('k') | third_party/boto/boto/ec2/autoscale/launchconfig.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698